@@ -1,7 +1,7 @@
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;;
-;; MODULE      : build-glue-basic.scm
+;; MODULE      : build-glue-editor.scm
 ;; DESCRIPTION : Building basic glue for the editor
 ;; COPYRIGHT   : (C) 1999  Joris van der Hoeven
 ;;
@@ -14,8 +14,6 @@
 
 (output-copyright "build-glue-editor.scm")
 
-(output "\n#module code_glue_editor\n")
-
 (build
   "get_server()->get_editor()->"
   "initialize_glue_editor"
@@ -23,6 +21,7 @@
   (key-press key_press (void string))
   (emulate-keyboard emulate_keyboard (void string))
   (emulate-keyboard-message emulate_keyboard (void string string))
+  (complete-try? complete_try (bool))
   
   (go-left go_left (void))
   (go-right go_right (void))
@@ -40,17 +39,11 @@
   (go-page-down go_page_down (void))
   (go-to-label go_to_label (void string))
 
-  (mouse-press mouse_press (void string int int))
-  (mouse-select mouse_select (void int int))
-  (mouse-paste mouse_paste (void int int))
-  (mouse-drag mouse_drag (void int int))
-  (mouse-adjust mouse_adjust (void int int))
-
   (select-all select_all (void))
   (select-line select_line (void))
   (select-from-cursor select_from_cursor (void))
   (select-from-keyboard select_from_keyboard (void bool))
-  (select-cursor-on-border? select_cursor_on_border (bool))
+  (select-from-shift-keyboard select_from_shift_keyboard (void))
   (select-enlarge select_enlarge (void))
   (select-enlarge-environmental select_enlarge_environmental (void))
   (selection-active-any? selection_active_any (bool))
@@ -60,17 +53,30 @@
   (selection-active-enlarging? selection_active_enlarging (bool))
   (selection-set-start selection_set_start (void))
   (selection-set-end selection_set_end (void))
-  (copy selection_copy (void string))
-  (cut selection_cut (void string))
-  (paste selection_paste (void string))
-  (move selection_move (void))
-  (selection-clear selection_clear (void string))
+  (selection-get-start selection_get_start (path))
+  (selection-get-end selection_get_end (path))
+  (selection-set-start-path selection_set_start (void path))
+  (selection-set-end-path selection_set_end (void path))
+  (clipboard-copy selection_copy (void string))
+  (clipboard-cut selection_cut (void string))
+  (clipboard-cut-at cut (void path))
+  (clipboard-paste selection_paste (void string))
+  (selection-move selection_move (void))
+  (clipboard-clear selection_clear (void string))
   (selection-cancel selection_cancel (void))
-  (selection-set-import selection_set_import (void string))
-  (selection-set-export selection_set_export (void string))
+  (clipboard-set-import selection_set_import (void string))
+  (clipboard-set-export selection_set_export (void string))
+  (clipboard-get-import selection_get_import (string))
+  (clipboard-get-export selection_get_export (string))
+  (remove-undo-mark remove_undo_mark (void))
+  (add-undo-mark add_undo_mark (void))
+  (unredoable-undo unredoable_undo (void))
+  (forget-undo forget_undo (void))
   (undo undo (void))
   (redo redo (void))
 
+  (in-graphics? inside_graphics (bool))
+
   (in-normal-mode? in_normal_mode (bool))
   (in-search-mode? in_search_mode (bool))
   (in-replace-mode? in_replace_mode (bool))
@@ -78,21 +84,21 @@
   (inside? inside (bool string))
   (inside-with? inside_with (bool string string))
   (inside-which inside_which (string scheme_tree))
+  (search-upwards search_upwards (path string))
+  (search-parent-upwards search_parent_upwards (path tree_label))
+  (search-upwards-in-set search_upwards_in_set (path scheme_tree))
   (search-start search_start (void bool))
   (search-button-next search_button_next (void))
   (replace-start replace_start (void string string bool))
   (spell-start spell_start (void))
   (spell-replace spell_replace (void string))
 
-  (insert-string insert_tree (void string))
-  (insert-tree insert_tree (void texmacs_tree))
+  (insert insert_tree (void content))
+  (insert-go-to insert_tree (void content path))
   (insert-return insert_return (void))
-  (remove-backwards remove_backwards (void))
-  (remove-forwards remove_forwards (void))
-  (remove-structure-backwards remove_structure_backwards (void))
-  (remove-structure-forwards remove_structure_forwards (void))
+  (remove-text remove_text (void bool))
+  (remove-structure remove_structure (void bool))
   (remove-structure-upwards remove_structure_upwards (void))
-  (make-format make_format (void string))
   (make-htab make_htab (void string))
   (make-space make_space (void string))
   (make-var-space make_space (void string string string))
@@ -111,10 +117,6 @@
     (void string bool string string string string string string))
 
   (make-group make_group (void))
-  (make-large-left make_large_left (void string))
-  (make-large-middle make_large_middle (void string))
-  (make-large-right make_large_right (void string))
-  (make-big-operator make_big_operator (void string))
   (make-lprime make_lprime (void string))
   (make-rprime make_rprime (void string))
   (make-below make_below (void))
@@ -129,18 +131,21 @@
   (make-tree make_tree (void))
   (inside-tree? inside_tree (bool))
   (branch-insert branch_insert (void bool))
-  (branch-delete branch_delete (void))
+  (branch-delete branch_delete (void bool))
 
-  (make-sub-table make_sub_table (void))
+  (make-subtable make_subtable (void))
   (table-disactivate table_disactivate (void))
   (table-extract-format table_extract_format (void))
   (table-insert-row table_insert_row (void bool))
   (table-insert-column table_insert_column (void bool))
   (table-delete-row table_delete_row (void bool))
   (table-delete-column table_delete_column (void bool))
-  (table-go-to table_go_to (void int int))
+  (table-nr-rows table_nr_rows (int))
+  (table-nr-columns table_nr_columns (int))
   (table-which-row table_which_row (int))
   (table-which-column table_which_column (int))
+  (table-search-cell table_search_cell (path int int))
+  (table-go-to table_go_to (void int int))
   (table-set-format table_set_format (void string string))
   (table-get-format table_get_format (string string))
   (table-del-format table_del_format (void string))
@@ -153,82 +158,87 @@
   (cell-get-format cell_get_format (string string))
   (cell-del-format cell_del_format (void string))
   (cell-multi-paragraph cell_multi_paragraph (void bool))
+  (cell-multi-paragraph? cell_is_multi_paragraph (bool))
   (table-test table_test (void))
 
-  (init-default init_default (void string))
+  (init-default-one init_default (void string))
   (init-env init_env (void string string))
-  (init-env-tree init_env (void string texmacs_tree))
+  (init-env-tree init_env (void string content))
   (init-style init_style (void string))
-  (init-extra-style init_extra_style (void string))
+  (init-add-package init_add_package (void string))
+  (init-remove-package init_remove_package (void string))
   (get-env get_env_string (string string))
-  (get-env-tree get_env_value (texmacs_tree string))
-  (get-init-tree get_init_value (texmacs_tree string))
+  (get-env-tree get_env_value (tree string))
+  (get-init-tree get_init_value (tree string))
   (context-has? defined_at_cursor (bool string))
   (style-has? defined_at_init (bool string))
-  (in-preamble-mode? in_preamble_mode (bool))
-  (is-deactivated? is_deactivated (bool))
+  (init-has? defined_in_init (bool string))
+  (menu-before-action before_menu_action (void))
+  (menu-after-action after_menu_action (void))
+  (make make_compound (void tree_label))
+  (make-arity make_compound (void tree_label int))
   (activate activate (void))
-  (make-active make_active (void string int))
-  (make-deactivated make_deactivated (void string int string))
-  (make-deactivated-arg make_deactivated (void string int string string))
-  (insert-argument insert_argument (void))
+  (insert-argument insert_argument (void bool))
+  (make-with make_with (void string string))
+  (make-mod-active make_mod_active (void tree_label))
+  (make-style-with make_style_with (void string string))
+  (make-hybrid make_hybrid (void))
+  (activate-latex activate_latex (void))
+  (activate-hybrid activate_hybrid (void bool))
+  (activate-symbol activate_symbol (void))
+  (activate-compound activate_compound (void))
   (make-return-before make_return_before (void))
   (make-return-after make_return_after (bool))
-  (make-assign make_assign (void string string))
-  (make-with make_with (void string string))
-  (make-big-expand make_big_expand (void string))
-  (make-expand make_expand (void string))
-  (make-expand-arity make_expand (void string int))
   (temp-proof-fix temp_proof_fix (void))
-  (make-apply make_apply (void string))
 
+  (view-set-property set_property (void scheme_tree scheme_tree))
+  (view-get-property get_property (scheme_tree scheme_tree))
   (clear-buffer clear_buffer (void))
   (tex-buffer tex_buffer (void))
+  (clear-local-info clear_local_info (void))
   (update-buffer typeset_invalidate_all (void))
   (generate-all-aux generate_aux (void))
   (generate-aux generate_aux (void string))
-  (set-page-parameters set_page_parameters (void))
-  (set-page-medium set_page_medium (void string))
-  (set-page-type set_page_type (void string))
-  (set-page-orientation set_page_orientation (void string))
-  (set-shrinking-factor set_shrinking_factor (void int))
-  (print-to-file print_to_file (void string))
-  (print-pages-to-file print_to_file (void string string string))
+  (notify-page-change notify_page_change (void))
+  (print-to-file print_to_file (void url))
+  (print-pages-to-file print_to_file (void url string string))
   (print print_buffer (void))
   (print-pages print_buffer (void string string))
-  (export-postscript export_ps (void string))
-  (export-pages-postscript export_ps (void string string string))
+  (export-postscript export_ps (void url))
+  (export-pages-postscript export_ps (void url string string))
   (set-message set_message (void string string))
-  (menu-main set_main_menu (void scheme_tree))
-  (menu-popup set_popup_menu (void scheme_tree))
-  (menu-icons set_icon_menu (void int scheme_tree))
 
-  (TeXmacs-eval eval (void string))
-  (TeXmacs-eval-tree eval (void scheme_tree))
-  (the-line the_line (texmacs_tree))
-  (the-selection selection_get (texmacs_tree))
-  (the-buffer the_buffer (texmacs_tree))
-  (shell-eval shell_eval (texmacs_tree texmacs_tree))
-  (edit-lisp-compile edit_lisp_compile (texmacs_tree texmacs_tree))
-  (edit-lisp-eval edit_lisp_eval (texmacs_tree texmacs_tree))
-  (prog-eval prog_eval (texmacs_tree texmacs_tree))
+  (footer-eval footer_eval (void string))
+  (the-line the_line (tree))
+  (the-selection selection_get (tree))
+  (the-root the_root (tree))
+  (the-buffer the_buffer (tree))
+  (the-path the_path (path))
+  (the-buffer-path the_buffer_path (path))
+  (the-mutator-path get_mutator_path (path))
+  (the-mutator-time get_mutator_time (int))
   (process-input process_input (void))
   (make-session make_session (void string string))
-  (start-input start_input (void))
-  (start-output start_output (void))
+  (start-input start_input (void string string path))
   (session-use-math-input session_use_math_input (void bool))
+  (session-math-input? session_is_using_math_input (bool))
   (session-go-up session_go_up (void))
   (session-go-down session_go_down (void))
   (session-go-left session_go_left (void))
   (session-go-right session_go_right (void))
   (session-go-page-up session_go_page_up (void))
   (session-go-page-down session_go_page_down (void))
-  (session-remove-backwards session_remove_backwards (void))
-  (session-get-input session_get_input (string))
-  (session-get-input-pos session_get_input_pos (int))
-  (session-set-input session_set_input (void string))
-  (session-set-input-pos session_set_input_pos (void int))
-  (interactive interactive (void scheme_tree scheme_tree))
+  (session-remove session_remove (void bool))
+  (session-insert-text-field session_insert_text_field (void))
+  (session-insert-input-above session_insert_input_above (void))
+  (session-insert-input-below session_insert_input_below (void))
+  (session-fold-input session_fold_input (void))
+  (session-remove-input session_remove_input (void bool))
+  (session-remove-all-outputs session_remove_all_outputs (void))
+  (session-remove-previous-output session_remove_previous_output (void))
+  (session-split session_split (void))
+  (session-complete-try? session_complete_try (bool))
+  (tm-interactive interactive (void scheme_tree object))
   (connection-busy? busy_connection (bool))
   (connection-interrupt interrupt_connection (void))
   (connection-stop stop_connection (void))
@@ -241,6 +251,39 @@
   (show-keymaps show_keymaps (void))
   (show-meminfo show_meminfo (void))
   (edit-special edit_special (void))
-  (edit-test edit_test (void)))
+  (edit-test edit_test (void))
 
-(output "\n#endmodule // code_glue_editor\n")
+  (length-decode as_length (int string))
+  (length-add add_lengths (string string string))
+  (length-mult multiply_length (string double string))
+  (length? is_length (bool string))
+  (length-divide divide_lengths (double string string))
+
+  (tm-subtree the_subtree (tree path))
+  (tm-assign assign (void path content))
+  (tm-insert insert (void path content))
+  (tm-remove remove (void path int))
+  (tm-split split (void path))
+  (tm-join join (void path))
+  (tm-ins-unary ins_unary (void path tree_label))
+  (tm-rem-unary rem_unary (void path))
+  (tm-assign-diff assign_diff (void path content))
+  (tm-correct correct (void path))
+  (tm-where current_position (path))
+  (tm-go-to go_to (void path))
+  (tm-go-to-start go_to_start (void path))
+  (tm-go-to-end go_to_end (void path))
+
+  (tm-position-new position_new (int))
+  (tm-position-delete position_delete (void int))
+  (tm-position-set position_set (void int path))
+  (tm-position-get position_get (path int))
+
+  (tm-insert-with insert_with (void path string content))
+  (tm-remove-with remove_with (void path string))
+
+  (get-graphical-object get_graphical_object (tree))
+  (set-graphical-object set_graphical_object (void tree))
+  (invalidate-graphical-object invalidate_graphical_object (void))
+  (graphical-select graphical_select (tree double double))
+  (texmacs-exec texmacs_exec (tree content)))
